<?php
/*
Plugin Name: Enhanced Categories
Version: 2.0.2
Plugin URI: http://enhanced-categories.vincentprat.info
Description: Allows to get better control over the category listing. Also provides a widget view of the categories. Please make a donation if you are satisfied.
Author: Vincent Prat
Author URI: http://www.vincentprat.info
*/

/*  Copyright 2006 Vincent Prat  (email : vpratfr@yahoo.fr)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Version of the plugin
define('ENHANCED_CATEGORIES_CURRENT_VERSION', '2.0.2' );

// i18n plugin domain 
define('ENHANCED_CATEGORIES_I18N_DOMAIN', 'enhanced-categories');

// Options
define('ENHANCED_CATEGORIES_VERSION_OPTION', 'enh_cats_version');

// you can deactivate the javascript effect by setting the next variable to false
define('ENHANCED_CATEGORIES_USE_JAVASCRIPT', true);

/**
 * Initialise the internationalisation domain
 */
$enh_cats_is_i18n_setup = false;
function enh_cats_init_i18n() {
	global $enh_cats_is_i18n_setup;

	if ($enh_cats_is_i18n_setup == false) {
		load_plugin_textdomain(ENHANCED_CATEGORIES_I18N_DOMAIN, 'wp-content/plugins/enhanced-categories');
		$enh_cats_is_i18n_setup = true;
	}
}

/**
 * Plugin activation
 */
add_action('activate_enhanced-categories/enhanced-categories.php','enh_cats_plugin_activation');
function enh_cats_plugin_activation() {
	$installed_version = enh_cats_get_installed_version();
	
	if ( $installed_version==enh_cats_get_current_version() ) {
		// do nothing
	} else if ( $installed_version=='' ) {
	} else if ($installed_version>='1.0' && $installed_version<'2.0.0') {
		remove_option('enh_cats_show_symbol');
		remove_option('enh_cats_hide_symbol');
		remove_option('enh_cats_no_child_symbol');
		remove_option('enh_cats_effect');
		remove_option('enh_cats_show_count');
		remove_option('enh_cats_show_rss');
		remove_option('enh_cats_hide_empty');	
		remove_option('enh_cats_button_before_link');
	}
	
	// Update version number
	update_option( ENHANCED_CATEGORIES_VERSION_OPTION, enh_cats_get_current_version() );	
}

/**
 * Wrapper for the option 'ENHANCED_CATEGORIES_version'
 */
function enh_cats_get_installed_version() {
	return get_option( ENHANCED_CATEGORIES_VERSION_OPTION );
}

/**
 * Wrapper for the defined constant ENHANCED_CATEGORIES_CURRENT_VERSION
 */
function enh_cats_get_current_version() {	
	return ENHANCED_CATEGORIES_CURRENT_VERSION;
}

if (ENHANCED_CATEGORIES_USE_JAVASCRIPT) {
/**
 * Function to insert the javascript in the page header
 */
add_action('wp_head', 'enh_cats_insert_javascript');
function enh_cats_insert_javascript() {
?>
<script src="<?php echo get_bloginfo('wpurl'); ?>/wp-content/plugins/enhanced-categories/enhanced-categories.js" type="text/javascript" ></script>
<?php
}
}

/**
* Function to list the categories in a template
*/
global $global_ul_index;
$global_ul_index = 0;

function enh_cats_list_categories($args = '') {	
	global $global_ul_index;
	$global_ul_index++;
	
	$defaults = array(
		// Options of the plugin
		'hide_empty' => 1, 
		'show_count' => 0,
		'show_rss' => '0',
		'exclude' => '',
		'button_color' => '#AA0000',
		'expand_text' => '&raquo;',
		'leaf_text' => '-',
		'contract_text' => '&laquo;',
		'contract_children' => 1,

		// Those are not set by the options
		'show_last_update' => 0,
		'show_option_all' => '', 
		'orderby' => 'name',
		'order' => 'ASC', 
		'use_desc_for_title' => 1,
		'child_of' => 0, 
		'hierarchical' => 1,
		'title_li' => ''
	);
	
	$r = wp_parse_args( $args, $defaults );

	if ($r['show_rss']!=0) {
		$r['feed'] = 'RSS';
		$r['feed_image'] = get_bloginfo('wpurl') . '/wp-content/plugins/enhanced-categories/rss.png';
	} else {
		$r['feed'] = '';
		$r['feed_image'] = '';
	}
	
	if (ENHANCED_CATEGORIES_USE_JAVASCRIPT) {
?>
		<script type="text/javascript">
			jQuery(document).ready(function() {
				jQuery('ul.enhanced-categories-<?php echo $global_ul_index; ?>').enhancedCategories({
					// Override here the default settings for the plugin
					expandText	: '<?php echo $r['expand_text']; ?>',
					contractText: '<?php echo $r['contract_text']; ?>',
					leafText	: '<?php echo $r['leaf_text']; ?>',
					buttonColor	: '<?php echo $r['button_color']; ?>',
					contractChildren: <?php echo $r['contract_children']; ?>
				});
			});
		</script>
<?php	
	}

	echo '<ul class="enhanced-categories-' . $global_ul_index . '">';
	wp_list_categories($r);
	echo '</ul>';
}

/**
* Function to list the categories in a widget
*/
function enh_cats_widget($args) {
	extract($args, EXTR_SKIP);
	$options = get_option('enh_cats_widget');
	$title = empty($options['widget_title']) ? __('Categories', ENHANCED_CATEGORIES_I18N_DOMAIN) : $options['widget_title'];

	echo $before_widget; 
		echo $before_title . $title . $after_title;
		enh_cats_list_categories($options); 
	echo $after_widget;
}

/**
* Widget settings window
*/
function enh_cats_widget_control() {
	// Get our options
	//--
	$options = get_option('enh_cats_widget');
	if ( !is_array($options) ) {
		$options = array(
			'widget_title'	=> '', 
			'show_rss'		=> 0, 
			'hide_empty' 	=> 1, 
			'show_count' 	=> 0,
			'exclude' 		=> '',
			'contract_children' => 1,
			'button_color' 	=> '#AA0000',
			'expand_text' 	=> '&raquo;',
			'contract_text' => '&laquo;',
			'leaf_text' 	=> '-'
		);
	}
	
	// See if we're handling a form submission
	//--
	if ( $_POST['enh_cats-submit'] ) {
		$options['widget_title'] 	= strip_tags(stripslashes($_POST['enh_cats-widget_title']));
		$options['hide_empty'] 		= $_POST['enh_cats-hide_empty'] ? 1 : 0;
		$options['show_rss'] 		= $_POST['enh_cats-show_rss'] 	? 1 : 0;
		$options['show_count'] 		= $_POST['enh_cats-show_count'] ? 1 : 0;
		$options['exclude']			= $_POST['enh_cats-exclude'] 	? 1 : 0;
		$options['contract_children']= $_POST['enh_cats-contract_children'] ? 1 : 0;
		$options['button_color']	= strip_tags(stripslashes($_POST['enh_cats-button_color']));
		$options['expand_text']		= strip_tags(stripslashes($_POST['enh_cats-expand_text']));
		$options['contract_text']	= strip_tags(stripslashes($_POST['enh_cats-contract_text']));
		$options['leaf_text']		= strip_tags(stripslashes($_POST['enh_cats-leaf_text']));
		
		update_option('enh_cats_widget', $options);
	}

	// The widget control
	//--
	$widget_title = htmlspecialchars($options['widget_title'], ENT_QUOTES);
?>
	<p>
		<label><?php _e('Title:', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/>
		<input style="width: 250px;" id="enh_cats-widget_title" name="enh_cats-widget_title" type="text" value="<?php echo $widget_title; ?>" /></label>
	</p>
	
	<br/>
	<p><strong>&raquo; <?php _e('Category listing options', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></strong></p>
	<p>
		<label><input class="checkbox" <?php enh_cats_checked($options['hide_empty']); ?> id="enh_cats-hide_empty" name="enh_cats-hide_empty" type="checkbox"> 
		<?php _e('Hide empty categories', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></label>
	</p>
	<p>
		<label><input class="checkbox" <?php enh_cats_checked($options['show_rss']); ?> id="enh_cats-show_rss" name="enh_cats-show_rss" type="checkbox"> 
		<?php _e('Show RSS', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></label>
	</p>
	<p>
		<label><input class="checkbox" <?php enh_cats_checked($options['show_count']); ?> id="enh_cats-show_count" name="enh_cats-show_count" type="checkbox"> 
		<?php _e('Show post count', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></label>
	</p>
	<p>
		<label><?php _e('Exclude categories (comma-separated IDs):', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/>
		<input style="width: 250px;" id="enh_cats-exclude" name="enh_cats-exclude" type="text" value="<?php echo $options['exclude']; ?>" /></label>
	</p>
	
<?php 	if (ENHANCED_CATEGORIES_USE_JAVASCRIPT) { ?>
	<br/>
	<p><strong>&raquo; <?php _e('Javascript options', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></strong></p>
	<p>
		<label><input class="checkbox" <?php enh_cats_checked($options['contract_children']); ?> id="enh_cats-contract_children" name="enh_cats-contract_children" type="checkbox"> 
		<?php _e('Contract children categories', ENHANCED_CATEGORIES_I18N_DOMAIN); ?></label>
	</p>
	<p>
		<label><?php _e('Button color:', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/>
		<input style="width: 250px;" id="enh_cats-button_color" name="enh_cats-button_color" type="text" value="<?php echo $options['button_color']; ?>" /></label>
	</p>
	<p>
		<label><?php _e('Expand button text:', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/> 
		<input style="width: 250px;" id="enh_cats-expand_text" name="enh_cats-expand_text" type="text" value="<?php echo $options['expand_text']; ?>" /></label>
	</p>
	<p>
		<label><?php _e('Contract button text:', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/>
		<input style="width: 250px;" id="enh_cats-contract_text" name="enh_cats-contract_text" type="text" value="<?php echo $options['contract_text']; ?>" /></label>
	</p>
	<p>
		<label><?php _e('Text when category has no child:', ENHANCED_CATEGORIES_I18N_DOMAIN); ?><br/>
		<input style="width: 250px;" id="enh_cats-leaf_text" name="enh_cats-leaf_text" type="text" value="<?php echo $options['leaf_text']; ?>" /></label>
	</p>
<?php } ?>
	
	<input type="hidden" id="enh_cats-submit" name="enh_cats-submit" value="1" />
<?php 	
}

/**
* Register the widget
*/
add_action('widgets_init', 'enh_cats_widget_init');
function enh_cats_widget_init() {
	register_sidebar_widget(__('Enhanced Categories', ENHANCED_CATEGORIES_I18N_DOMAIN), 'enh_cats_widget');
	register_widget_control(__('Enhanced Categories', ENHANCED_CATEGORIES_I18N_DOMAIN), 'enh_cats_widget_control', 400, 250);
}

/**
* Helper function to output the checked attribute of a checkbox
*/
function enh_cats_checked($var) {
	if ($var==1 || $var==true)
		echo 'checked="checked"';
}
?>